@@ -4,6 +4,7 @@ fn main() {
     let _ = App::new()
         .name("Fibonacci App")
         .version("1.0")
+        .long_desc("This app can be used to calculate fibonacci numbers")
         .command(
             Command::new("fib")
                 .opt(
@@ -22,7 +23,7 @@ fn main() {
 fn fibonacci_handler(_app: &App, ctx: &Context, _args: &[String]) {
     let v = fibonacci(
         ctx.get_string("count")
-            .unwrap_or("1".to_string())
+            .unwrap_or_else(|| "1".to_string())
             .parse()
             .unwrap_or(1),
     );
