@@ -1,9 +1,14 @@
+#[macro_use]
+mod macros;
+
 mod app;
 mod command;
 mod context;
 mod opt;
+pub use console;
 pub mod vox;
 pub use app::*;
 pub use command::*;
 pub use context::*;
 pub use opt::*;
+pub use vox::*;
